@@ -55,9 +55,17 @@ OC.L10N.register(
     "Deck" : "Pakka",
     "Changes in the <strong>Deck app</strong>" : "Muutokset <strong>Pakka-sovelluksessa</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Kommentti</strong> luotiin kortille",
+    "The file was uploaded" : "Tiedosto lähetettiin",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedostossa määritellyn upload_max_filesize -säännön ",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
+    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
+    "No file was uploaded" : "Tiedostoa ei lähetetty",
+    "Missing a temporary folder" : "Väliaikaistiedostojen kansio puuttuu",
+    "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
+    "A PHP extension stopped the file upload" : "PHP:n laajennus esti tiedoston lähettämisen",
+    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
     "Upcoming cards" : "Tulevat kortit",
     "Load more" : "Lataa lisää",
-    "Personal" : "Henkilökohtainen",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortti \"%s\" taululla \"%s\" on asetettu sinulle käyttäjän %s toimesta.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortin \"%s\" on \"%s\" eräpäivä on tullut vastaan.",
     "%s has mentioned you in a comment on \"%s\"." : "%s mainitsi sinut kommentissa kortilla \"%s\".",
@@ -71,45 +79,33 @@ OC.L10N.register(
     "Action needed" : "Toimia vaaditaan",
     "Later" : "Myöhemmin",
     "copy" : "kopioi",
-    "To do" : "Odottaa",
-    "Doing" : "Tekeillä",
+    "To Do" : "Tehtävä",
     "Done" : "Valmis",
-    "Example Task 3" : "Esimerkkitehtävä 3",
-    "Example Task 2" : "Esimerkkitehtävä 2",
-    "Example Task 1" : "Esimerkkitehtävä 1",
-    "The file was uploaded" : "Tiedosto lähetettiin",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedostossa määritellyn upload_max_filesize -säännön ",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
-    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
-    "No file was uploaded" : "Tiedostoa ei lähetetty",
-    "Missing a temporary folder" : "Väliaikaistiedostojen kansio puuttuu",
-    "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
-    "A PHP extension stopped the file upload" : "PHP:n laajennus esti tiedoston lähettämisen",
-    "No file uploaded or file size exceeds maximum of %s" : "Tiedostoa ei lähetetty tai sen koko ylitti maksimin %s",
+    "Attachments" : "Liitteet",
+    "File" : "Tiedosto",
     "Card not found" : "Korttia ei löydy",
     "Path is already shared with this card" : "Polku on jo jaettu tämän kortin kanssa",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päivä, päivän muodon tulee olla YYYY-MM-DD",
-    "Card details" : "Näytä kortin sisältö",
     "Add board" : "Lisää taulu",
+    "Card details" : "Näytä kortin sisältö",
     "Select the board to link to a project" : "Valitse projektiin linkitettävä taulu",
     "Search by board title" : "Hae taulun otsikon mukaan",
     "Select board" : "Valitse taulu",
-    "Move card to another board" : "Siirrä kortti toiselle taululle",
     "Select a board" : "Valitse taulu",
     "No lists available" : "Ei listoja saatavilla",
     "Select a list" : "Valitse lista ",
     "Move card" : "Siirrä kortti",
-    "Cancel" : "Peruuta",
-    "Select a card" : "Valitse kortti",
     "Select the card to link to a project" : "Valitse projektiin linkitettävä kortti",
     "Link to card" : "Linkitä korttiin",
+    "Select a card" : "Valitse kortti",
+    "Cancel" : "Peruuta",
+    "This board is read only" : "Tämä taulu on kirjoitussuojattu",
+    "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
     "File already exists" : "Tiedosto on jo olemassa",
     "A file with the name {filename} already exists." : "Tiedosto nimellä {filename} on jo olemassa.",
     "Do you want to overwrite it?" : "Haluatko ylikirjoittaa sen?",
     "Overwrite file" : "Päällekirjoita tiedosto",
     "Keep existing file" : "Pidä nykyinen tiedosto",
-    "This board is read only" : "Tämä taulu on kirjoitussuojattu",
-    "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
     "Add card" : "Lisää kortti",
     "Archived cards" : "Arkistoidut kortit",
     "Add list" : "Lisää lista",
@@ -117,12 +113,13 @@ OC.L10N.register(
     "Active filters" : "Aktiiviset suodattimet",
     "Apply filter" : "Toteuta suodatus",
     "Filter by tag" : "Suodata tunnisteen perusteella",
-    "Filter by assigned user" : "Suodata määritetyn käyttäjän mukaan",
+    "Filter by assigned user" : "Suodata määritetyn käyttäjän perusteella",
     "Unassigned" : "Määrittämätön",
+    "Filter by status" : "Suodata tilan perusteella",
     "Open and completed" : "Avoimet ja valmiit",
     "Open" : "Avoimet",
     "Completed" : "Valmiit",
-    "Filter by due date" : "Suodata määräpäivän mukaan",
+    "Filter by due date" : "Suodata määräpäivän perusteella",
     "Overdue" : "Myöhässä",
     "Next 24 hours" : "Seuraavat 24 tuntia",
     "Next 7 days" : "Seuraavat 7 päivää",
@@ -146,6 +143,9 @@ OC.L10N.register(
     "Deleted lists" : "Poistetut listat",
     "Undo" : "Kumoa",
     "Deleted cards" : "Poistetut kortit",
+    "Failed to create share with {displayName}" : "Jaon luonti epäonnistui kohteen {displayName} kanssa",
+    "Are you sure you want to transfer the board {title} to {user}?" : "Haluatko varmasti siirtää taulun {title} käyttäjälle {user}?",
+    "Transfer" : "Siirrä",
     "Share board with a user, group or team …" : "Jaa taulu käyttäjän, ryhmän tai tiimin kanssa...",
     "No participants found" : "Ei osallistujia löydetty",
     "Board owner" : "Taulun omistaja",
@@ -155,20 +155,19 @@ OC.L10N.register(
     "Can manage" : "Voi hallita",
     "Owner" : "Omistaja",
     "Delete" : "Poista",
-    "Failed to create share with {displayName}" : "Jaon luonti epäonnistui kohteen {displayName} kanssa",
-    "Are you sure you want to transfer the board {title} to {user}?" : "Haluatko varmasti siirtää taulun {title} käyttäjälle {user}?",
-    "Transfer" : "Siirrä",
+    "List deleted" : "Lista poistettu",
     "Archive all cards" : "Arkistoi kaikki kortit",
     "Delete list" : "Poista lista",
     "Archive all cards in this list" : "Arkistoi kaikki kortit tässä listassa",
     "Add a new card" : "Lisää uusi kortti",
     "Card name" : "Kortin nimi",
-    "List deleted" : "Lista poistettu",
+    "title and color value must be provided" : "tunnisteella on oltava nimi ja väri",
     "Edit" : "Muokkaa",
     "Add a new tag" : "Lisää uusi tunniste",
-    "title and color value must be provided" : "tunnisteella on oltava nimi ja väri",
     "Board name" : "Taulun nimi",
     "Members" : "Jäsenet",
+    "File to share" : "Jaettava tiedosto",
+    "Invalid path selected" : "Virheellinen polku valittu",
     "Upload new files" : "Lähetä uusia tiedostoja",
     "Share from Files" : "Jaa tiedostoista",
     "Pending share" : "Odottava jako",
@@ -177,24 +176,22 @@ OC.L10N.register(
     "Remove attachment" : "Poista liite",
     "Delete Attachment" : "Poista liite",
     "Restore Attachment" : "Palauta liite",
-    "File to share" : "Jaettava tiedosto",
-    "Invalid path selected" : "Virheellinen polku valittu",
-    "Open in sidebar view" : "Avaa sivupalkkinäkymään",
-    "Attachments" : "Liitteet",
-    "Comments" : "Kommentit",
     "Modified" : "Muokattu",
     "Created" : "Luotu",
     "The title cannot be empty." : "Otsikko ei voi olla tyhjä.",
-    "No comments yet. Begin the discussion!" : "Ei vielä kommentteja. Aloita keskustelu!",
+    "Open in sidebar view" : "Avaa sivupalkkinäkymään",
+    "Comments" : "Kommentit",
     "Failed to load comments" : "Kommenttien lataaminen epäonnistui",
-    "Save" : "Tallenna",
+    "No comments yet. Begin the discussion!" : "Ei vielä kommentteja. Aloita keskustelu!",
     "The comment cannot be empty." : "Kommentti ei voi olla tyhjä.",
     "The comment cannot be longer than 1000 characters." : "Kommentin on oltava alle 1000 merkkiä pitkä.",
+    "Save" : "Tallenna",
+    "Created:" : "Luotu:",
     "In reply to" : "Vastauksena",
     "Cancel reply" : "Peru vastaus",
     "Reply" : "Vastaa",
     "Update" : "Päivitä",
-    "Created:" : "Luotu:",
+    "Write a description …" : "Kirjoita kuvaus…",
     "Description" : "Kuvaus",
     "(Unsaved)" : "(Tallentamaton)",
     "(Saving…)" : "(Tallennetaan…)",
@@ -202,24 +199,29 @@ OC.L10N.register(
     "Edit description" : "Muokkaa kuvausta",
     "View description" : "Näytä kuvaus",
     "Add Attachment" : "Lisää liite",
-    "Write a description …" : "Kirjoita kuvaus…",
     "Choose attachment" : "Valitse liite",
+    "Select Date" : "Valitse päivä",
+    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "Set a due date" : "Aseta eräpäivä",
+    "Choose a date" : "Valitse päivämäärä",
     "Remove due date" : "Poista eräpäivä",
     "Mark as done" : "Merkitse valmiiksi",
     "Unarchive card" : "Poista kortti arkistosta",
     "Archive card" : "Arkistoi kortti",
-    "Select Date" : "Valitse päivä",
     "Assign a tag to this card…" : "Lisää kortille tunniste...",
     "Create a new tag:" : "Luo uusi tunniste:",
     "(group)" : "(ryhmä)",
-    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "{count} comments, {unread} unread" : "{count} kommenttia, {unread} lukematonta",
     "Edit card title" : "Muokkaa kortin otsikkoa",
+    "Open link" : "Avaa linkki",
+    "Card deleted" : "Kortti poistettu",
+    "Edit title" : "Muokkaa otsikkoa",
     "Assign to me" : "Määritä minulle",
     "Unassign myself" : "Poista määritys minulta",
     "Delete card" : "Poista kortti",
-    "Card deleted" : "Kortti poistettu",
     "seconds ago" : "sekuntia sitten",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Keyboard shortcut" : "Näppäimistön pikanäppäin",
@@ -233,30 +235,34 @@ OC.L10N.register(
     "Deck settings" : "Pakan asetukset",
     "Show boards in calendar/tasks" : "Näytä taulut kalenterissa ja tehtävissä",
     "Cancel edit" : "Peruuta muokkaus",
+    "Board {0} deleted" : "Taulu {0} poistettu",
+    "All cards" : "Kaikki kortit",
+    "No reminder" : "Ei muistutusta",
+    "An error occurred" : "Tapahtui virhe",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Haluatko varmasti poistaa taulun {title}? Tämä poistaa kaikki taulun tiedot, mukaan lukien arkistoidut kortit.",
+    "Delete the board?" : "Poistetaanko tämä taulu?",
     "Board details" : "Taulun tiedot",
     "Edit board" : "Muokkaa taulua",
     "Clone board" : "Monista taulu",
     "Unarchive board" : "Kumoa taulun arkistointi",
     "Archive board" : "Arkistoi taulu",
     "Export board" : "Vie taulu",
-    "All cards" : "Kaikki kortit",
     "No notifications" : "Ei ilmoituksia",
     "Delete board" : "Poista taulu",
-    "Board {0} deleted" : "Taulu {0} poistettu",
-    "No reminder" : "Ei muistutusta",
-    "An error occurred" : "Tapahtui virhe",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Haluatko varmasti poistaa taulun {title}? Tämä poistaa kaikki taulun tiedot, mukaan lukien arkistoidut kortit.",
-    "Delete the board?" : "Poistetaanko tämä taulu?",
-    "Today" : "Tänään",
-    "Tomorrow" : "Huomenna",
+    "Clone cards" : "Kloonaa kortteja",
+    "Advanced options" : "Lisävalinnat",
+    "Clone" : "Kloonaa",
+    "Export as CSV" : "Vie CSV:nä",
+    "Export" : "Vie",
     "Search for {searchQuery} in all boards" : "Hae ehtoja {searchQuery} kaikilta tauluilta",
     "No results found" : "Ei tuloksia",
-    "Click to expand description" : "Laajenna kuvausta ",
     "{nbCards} cards" : "{nbCards} korttia    ",
+    "Due on {date}" : "Määräpäivä {date}",
+    "Click to expand description" : "Laajenna kuvausta ",
     "Click to expand comment" : "Napsauta laajentaaksesi kommentin",
+    "Create card" : "Luo kortti",
     "Create a new card" : "Luo uusi kortti",
     "Card title" : "Kortin otsikko",
-    "Create card" : "Luo kortti",
     "Creating the new card …" : "Luodaan uutta korttia…",
     "Card \"{card}\" was added to \"{board}\"" : "Kortti \"{card}\" lisättiin taululle \"{board}\"",
     "Open card" : "Avaa kortti",
@@ -264,18 +270,23 @@ OC.L10N.register(
     "No upcoming cards" : "Ei tulevia kortteja",
     "upcoming cards" : "tulevat kortit",
     "New card" : "Uusi kortti",
-    "Due on {date}" : "Määräpäivä {date}",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
-    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Link to a board" : "Linkki taululle",
     "Link to a card" : "Linkitä korttiin",
     "Create a card" : "Luo kortti",
     "Something went wrong" : "Jokin meni vikaan",
     "Failed to upload {name}" : "Ei voitu lähettää {name}",
     "Maximum file size of {size} exceeded" : "Tiedoston enimmäiskoko {size} ylitetty",
+    "Due date" : "Eräpäivä",
     "Error creating the share" : "Virhe jakoa luotaessa",
     "Share" : "Jaa",
-    "(Circle)" : "(Piiri)"
+    "Personal" : "Henkilökohtainen",
+    "To do" : "Odottaa",
+    "Doing" : "Tekeillä",
+    "Example Task 3" : "Esimerkkitehtävä 3",
+    "Example Task 2" : "Esimerkkitehtävä 2",
+    "Example Task 1" : "Esimerkkitehtävä 1",
+    "Move card to another board" : "Siirrä kortti toiselle taululle",
+    "Today" : "Tänään",
+    "Tomorrow" : "Huomenna"
 },
 "nplurals=2; plural=(n != 1);");
