@@ -66,9 +66,17 @@ OC.L10N.register(
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Promjene u <strong>aplikaciji Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Na kartici je stvoren <strong>komentar</strong>",
+    "The file was uploaded" : "Datoteka je otpremljena",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
+    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
+    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
+    "Missing a temporary folder" : "Nedostaje privremena mapa",
+    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
+    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
+    "No file uploaded or file size exceeds maximum of %s" : "Nijedna datoteka nije otpremljena ili veličina datoteke premašuje maksimalnu veličinu od %s",
     "Upcoming cards" : "Nadolazeće kartice",
     "Load more" : "Učitaj više",
-    "Personal" : "Osobno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
@@ -86,45 +94,34 @@ OC.L10N.register(
     "Action needed" : "Potrebna radnja",
     "Later" : "Kasnije",
     "copy" : "kopiraj",
-    "To do" : "Zadatak",
-    "Doing" : "U postupku",
+    "To Do" : "Zadatak",
     "Done" : "Gotovo",
-    "Example Task 3" : "Primjer zadatka 3.",
-    "Example Task 2" : "Primjer zadatka 2.",
-    "Example Task 1" : "Primjer zadatka 1.",
-    "The file was uploaded" : "Datoteka je otpremljena",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
-    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
-    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
-    "Missing a temporary folder" : "Nedostaje privremena mapa",
-    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
-    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
-    "No file uploaded or file size exceeds maximum of %s" : "Nijedna datoteka nije otpremljena ili veličina datoteke premašuje maksimalnu veličinu od %s",
+    "Attachments" : "Privici",
+    "File" : "Datoteka",
     "Card not found" : "Kartica nije pronađena",
     "Path is already shared with this card" : "Put je već podijeljen s ovom karticom",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
     "Personal planning and team project organization" : "Osobno planiranje i organizacija timskih projekata",
     "Add board" : "Dodaj ploču",
+    "Card details" : "Pojedinosti o kartici",
     "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
     "Search by board title" : "Traži po naslovu ploče",
     "Select board" : "Odaberi ploču",
-    "Move card to another board" : "Premjesti karticu na drugu ploču",
     "Select a board" : "Odaberite ploču",
     "No lists available" : "Nema dostupnih popisa",
     "Select a list" : "Odaberi popis",
     "Move card" : "Premjesti karticu",
-    "Cancel" : "Odustani",
-    "Select a card" : "Odaberite karticu",
     "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
     "Link to card" : "Poveznica na karticu",
+    "Select a card" : "Odaberite karticu",
+    "Cancel" : "Odustani",
+    "This board is read only" : "Ova je ploča samo za čitanje",
+    "Drop your files to upload" : "Ispustite datoteke za otpremu",
     "File already exists" : "Datoteka već postoji",
     "A file with the name {filename} already exists." : "Datoteka s nazivom {filename} već postoji.",
     "Do you want to overwrite it?" : "Želite li prepisati?",
     "Overwrite file" : "Prepiši datoteku",
     "Keep existing file" : "Zadrži postojeću datoteku",
-    "This board is read only" : "Ova je ploča samo za čitanje",
-    "Drop your files to upload" : "Ispustite datoteke za otpremu",
     "Add card" : "Dodaj karticu",
     "Archived cards" : "Arhivirane kartice",
     "Add list" : "Dodaj popis",
@@ -157,6 +154,8 @@ OC.L10N.register(
     "Deleted lists" : "Izbrisani popisi",
     "Undo" : "Poništi",
     "Deleted cards" : "Izbrisane kartice",
+    "Failed to create share with {displayName}" : "Dijeljenje s {displayName} nije uspjelo",
+    "Transfer" : "Prijenos",
     "No participants found" : "Nije pronađen nijedan sudionik",
     "Board owner" : "Vlasnik ploče",
     "(Group)" : "(Grupa)",
@@ -165,20 +164,20 @@ OC.L10N.register(
     "Can manage" : "Upravljanje moguće",
     "Owner" : "Vlasnik",
     "Delete" : "Izbriši",
-    "Failed to create share with {displayName}" : "Dijeljenje s {displayName} nije uspjelo",
-    "Transfer" : "Prijenos",
+    "List deleted" : "Popis je izbrisan",
     "Archive all cards" : "Arhiviraj sve kartice",
     "Delete list" : "Izbriši popis",
     "Archive all cards in this list" : "Arhiviraj sve kartice s ovog popisa",
     "Add a new card" : "Dodaj novu karticu",
     "Card name" : "Naziv kartice",
-    "List deleted" : "Popis je izbrisan",
+    "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
     "Edit" : "Uredi",
     "Add a new tag" : "Dodaj novu oznaku",
-    "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
     "Board name" : "Naziv ploče",
     "Members" : "Članovi",
     "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
+    "File to share" : "Datoteka za dijeljenje",
+    "Invalid path selected" : "Odabran nevažeći put",
     "Upload new files" : "Otpremi nove datoteke",
     "Share from Files" : "Dijeli iz datoteka",
     "Add this attachment" : "Dodajte ovaj privitak",
@@ -186,25 +185,23 @@ OC.L10N.register(
     "Download" : "Preuzmi",
     "Delete Attachment" : "Izbriši privitak",
     "Restore Attachment" : "Vrati privitak",
-    "File to share" : "Datoteka za dijeljenje",
-    "Invalid path selected" : "Odabran nevažeći put",
-    "Open in sidebar view" : "Otvori u bočnom prikazu",
-    "Open in bigger view" : "Otvori u većem prikazu",
-    "Attachments" : "Privici",
-    "Comments" : "Komentari",
     "Modified" : "Promijenjeno",
     "Created" : "Stvoreno",
     "The title cannot be empty." : "Naslov ne može biti prazan.",
-    "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
+    "Open in sidebar view" : "Otvori u bočnom prikazu",
+    "Open in bigger view" : "Otvori u većem prikazu",
+    "Comments" : "Komentari",
     "Failed to load comments" : "Učitavanje komentara nije uspjelo",
-    "Save" : "Spremi",
+    "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
     "The comment cannot be empty." : "Komentar ne može biti prazan.",
     "The comment cannot be longer than 1000 characters." : "Komentar ne može duži od 1000 znakova.",
+    "Save" : "Spremi",
+    "Created:" : "Stvoreno:",
     "In reply to" : "Kao odgovor",
     "Cancel reply" : "Prekini odgovor",
     "Reply" : "Odgovori",
     "Update" : "Ažuriraj",
-    "Created:" : "Stvoreno:",
+    "Write a description …" : "Napišite opis...",
     "Description" : "Opis",
     "(Unsaved)" : "(Nije spremljeno)",
     "(Saving…)" : "(Spremanje…)",
@@ -212,22 +209,21 @@ OC.L10N.register(
     "Edit description" : "Uredi opis",
     "View description" : "Prikaži opis",
     "Add Attachment" : "Dodaj privitak",
-    "Write a description …" : "Napišite opis...",
     "Choose attachment" : "Odaberi privitak",
+    "Select Date" : "Odaberi datum",
     "Set a due date" : "Postavi datum dospijeća",
     "Remove due date" : "Ukloni datum dospijeća",
     "Mark as done" : "Označi kao završeno",
     "Unarchive card" : "Dearhiviraj karticu",
     "Archive card" : "Arhiviraj karticu",
-    "Select Date" : "Odaberi datum",
     "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
     "(group)" : "(grupa)",
     "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
-    "Card details" : "Pojedinosti o kartici",
+    "Card deleted" : "Kartica je izbrisana",
+    "Edit title" : "Uredi naslov",
     "Assign to me" : "Dodijeli meni",
     "Unassign myself" : "Ukloni sebe",
     "Delete card" : "Izbriši karticu",
-    "Card deleted" : "Kartica je izbrisana",
     "seconds ago" : "prije nekoliko sekundi",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Keyboard shortcut" : "Tipkovni prečac",
@@ -239,6 +235,13 @@ OC.L10N.register(
     "Shared with you" : "Podijeljeno s vama",
     "Use bigger card view" : "Prikaži veće kartice",
     "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
+    "Cancel edit" : "Otkaži uređivanje",
+    "Board {0} deleted" : "Ploča {0} je izbrisana",
+    "All cards" : "Sve kartice",
+    "Only assigned cards" : "Samo dodijeljene kartice",
+    "No reminder" : "Nema podsjetnika",
+    "An error occurred" : "Došlo je do pogreške",
+    "Delete the board?" : "Želite li izbrisati ploču?",
     "Board details" : "Pojedinosti o ploči",
     "Edit board" : "Uredi ploču",
     "Clone board" : "Kloniraj ploču",
@@ -247,25 +250,20 @@ OC.L10N.register(
     "Turn on due date reminders" : "Uključi podsjetnike datuma dospijeća",
     "Turn off due date reminders" : "Isključi podsjetnike datuma dospijeća",
     "Due date reminders" : "Podsjetnici datuma dospijeća",
-    "All cards" : "Sve kartice",
     "Assigned cards" : "Dodijeljene kartice",
     "No notifications" : "Nema obavijesti",
     "Delete board" : "Izbriši ploču",
-    "Board {0} deleted" : "Ploča {0} je izbrisana",
-    "Only assigned cards" : "Samo dodijeljene kartice",
-    "No reminder" : "Nema podsjetnika",
-    "An error occurred" : "Došlo je do pogreške",
-    "Delete the board?" : "Želite li izbrisati ploču?",
+    "Clone cards" : "Kloniraj kartice",
+    "Advanced options" : "Napredne opcije",
+    "Clone" : "Kloniraj",
+    "Export" : "Izvoz",
     "Loading filtered view" : "Učitavanje filtriranog prikaza",
-    "Today" : "Danas",
-    "Tomorrow" : "Sutra",
-    "No due" : "Nema nezavršenih",
     "Search for {searchQuery} in all boards" : "Traži {searchQuery} na svim pločama",
     "No results found" : "Nema rezultata",
     "{stack} in {board}" : "{stack} u {board}",
+    "Create card" : "Stvori karticu",
     "Create a new card" : "Stvori novu karticu",
     "Card title" : "Naslov kartice",
-    "Create card" : "Stvori karticu",
     "Creating the new card …" : "Stvaranje nove kartice…",
     "Card \"{card}\" was added to \"{board}\"" : "Kartica „{card}” je dodana na „{board}”",
     "Open card" : "Otvori karticu",
@@ -279,20 +277,20 @@ OC.L10N.register(
     "Something went wrong" : "Nešto je pošlo po krivu",
     "Failed to upload {name}" : "Neuspješno otpremanje {name}",
     "Maximum file size of {size} exceeded" : "Prekoračena je maksimalna veličina datoteke od {size}",
+    "Due date" : "Datum dospijeća",
     "Error creating the share" : "Pogreška pri stvaranju dijeljenja",
     "Share with a Deck card" : "Dijeli s Deck karticom",
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Promijenjen je <strong>opis kartice</strong> u aplikaciji Deck",
-    "Timeline" : "Vremenska crta",
-    "Share board with a user, group or circle …" : "Dijelite ploču s korisnikom, grupom ili krugom...",
-    "Searching for users, groups and circles …" : "Traženje korisnika, grupa i krugova...",
-    "(Circle)" : "(Krug)",
-    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima",
-    "Next week" : "Sljedeći tjedan",
-    "Next month" : "Sljedeći mjesec",
-    "List is empty" : "Popis je prazan",
-    "Limit deck usage of groups" : "Ograniči uporabu decka grupama",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograničenjem Decka možete spriječiti korisnike koji ne sudjeluju u tim grupama da stvaraju vlastite ploče. Korisnici će i dalje moći raditi na pločama koje su dijeljene s njima."
+    "Personal" : "Osobno",
+    "To do" : "Zadatak",
+    "Doing" : "U postupku",
+    "Example Task 3" : "Primjer zadatka 3.",
+    "Example Task 2" : "Primjer zadatka 2.",
+    "Example Task 1" : "Primjer zadatka 1.",
+    "Move card to another board" : "Premjesti karticu na drugu ploču",
+    "Today" : "Danas",
+    "Tomorrow" : "Sutra",
+    "No due" : "Nema nezavršenih"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
