@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -7,10 +8,12 @@ namespace OCA\Deck\Model;
 
 use OCA\Deck\Db\Board;
 use OCA\Deck\Db\Card;
+use OCP\Collaboration\Reference\Reference;
 
 class CardDetails extends Card {
 	private Card $card;
 	private ?Board $board;
+	private ?Reference $referenceData = null;
 
 	public function __construct(Card $card, ?Board $board = null) {
 		parent::__construct();
@@ -22,6 +25,10 @@ class CardDetails extends Card {
 		$this->board = $board;
 	}
 
+	public function setReferenceData(?Reference $data): void {
+		$this->referenceData = $data;
+	}
+
 	public function jsonSerialize(array $extras = []): array {
 		$array = parent::jsonSerialize();
 		$array['overdue'] = $this->getDueStatus();
@@ -37,6 +44,8 @@ class CardDetails extends Card {
 		$array['overdue'] = $this->getDueStatus();
 		$this->appendBoardDetails($array);
 
+		$array['referenceData'] = $this->referenceData?->jsonSerialize();
+
 		return $array;
 	}
 
